antares.apps.terminal.tests package — Antares 0.0.2 documentation

# antares.apps.terminal.tests package

## Submodules

## antares.apps.terminal.tests.remote_terminal_test module

Created on Jun 23, 2016

@author: leobelen

class `antares.apps.terminal.tests.remote_terminal_test.` `RemoteTerminalTest`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  `setup`()
  `testA`()

## Module contents

class `antares.apps.terminal.tests.` `RemoteTerminalTest`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  `setup`()
  `testA`()